==> app_installer-0.1.0.tar.gz: example/lib/main.dart <==
import 'package:flutter/material.dart';
import 'package:app_installer/app_installer.dart';

void main() => runApp(MyApp());

class MyApp extends StatefulWidget {
  @override
  _MyAppState createState() => _MyAppState();
}

class _MyAppState extends State<MyApp> {
  /// 应用市场信息
  String androidAppId = 'com.tengyue360.student';
  String iOSAppId = '1440249706';

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: Scaffold(
        appBar: AppBar(
          title: const Text('Plugin example app'),
        ),
        body: Center(
          child: Column(
            children: <Widget>[
              SizedBox(height: 80),
              FlatButton.icon(
                onPressed: () {
                  AppInstaller.goStore(androidAppId, iOSAppId);
                },
                icon: Icon(Icons.store),
                label: Text('Go Store'),
              ),
              SizedBox(height: 40),
              FlatButton.icon(
                onPressed: () {
                  AppInstaller.goStore(androidAppId, iOSAppId, review: true);
                },
                icon: Icon(Icons.rate_review),
                label: Text('Go Store Review'),
              ),
              SizedBox(height: 40),
              FlatButton.icon(
                onPressed: () {
                  AppInstaller.installApk('/sdcard/apk/app-debug.apk');
                },
                icon: Icon(Icons.arrow_downward),
                label: Text('Install Apk'),
              ),
            ],
          ),
        ),
      ),
    );
  }
}

==> app_installer-0.4.0.tar.gz: example/lib/main.dart <==
import 'package:flutter/material.dart';
import 'package:app_installer/app_installer.dart';

void main() => runApp(MyApp());

class MyApp extends StatefulWidget {
  @override
  _MyAppState createState() => _MyAppState();
}

class _MyAppState extends State<MyApp> {
  /// 应用市场信息
  String androidAppId = 'com.tengyue360.student';
  String iOSAppId = '1440249706';

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: Scaffold(
        appBar: AppBar(
          title: const Text('Plugin example app'),
        ),
        body: Center(
          child: Column(
            children: <Widget>[
              SizedBox(height: 80),
              FlatButton.icon(
                onPressed: () {
                  AppInstaller.goStore(androidAppId, iOSAppId);
                },
                icon: Icon(Icons.store),
                label: Text('Go Store'),
              ),
              SizedBox(height: 40),
              FlatButton.icon(
                onPressed: () {
                  AppInstaller.goStore(androidAppId, iOSAppId, review: true);
                },
                icon: Icon(Icons.rate_review),
                label: Text('Go Store Review'),
              ),
              SizedBox(height: 40),
              FlatButton.icon(
                onPressed: () {
                  AppInstaller.installApk('/sdcard/app/app-debug.apk');
                },
                icon: Icon(Icons.arrow_downward),
                label: Text('Install Apk'),
              ),
            ],
          ),
        ),
      ),
    );
  }
}
